#[non_exhaustive]pub struct DeleteDataCatalogInput {
pub name: Option<String>,
pub delete_catalog_only: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the data catalog to delete.
delete_catalog_only: Option<bool>Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Implementations
Sourceimpl DeleteDataCatalogInput
impl DeleteDataCatalogInput
Sourcepub fn delete_catalog_only(&self) -> Option<bool>
pub fn delete_catalog_only(&self) -> Option<bool>
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Sourceimpl DeleteDataCatalogInput
impl DeleteDataCatalogInput
Sourcepub fn builder() -> DeleteDataCatalogInputBuilder
pub fn builder() -> DeleteDataCatalogInputBuilder
Creates a new builder-style object to manufacture DeleteDataCatalogInput.