#[non_exhaustive]pub struct DeleteDataCatalogOutput {
pub data_catalog: Option<DataCatalog>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_catalog: Option<DataCatalog>Contains information about a data catalog in an Amazon Web Services account.
In the Athena console, data catalogs are listed as "data sources" on the Data sources page under the Data source name column.
Implementations
Sourceimpl DeleteDataCatalogOutput
impl DeleteDataCatalogOutput
Sourcepub fn data_catalog(&self) -> Option<&DataCatalog>
pub fn data_catalog(&self) -> Option<&DataCatalog>
Contains information about a data catalog in an Amazon Web Services account.
In the Athena console, data catalogs are listed as "data sources" on the Data sources page under the Data source name column.
Sourceimpl DeleteDataCatalogOutput
impl DeleteDataCatalogOutput
Sourcepub fn builder() -> DeleteDataCatalogOutputBuilder
pub fn builder() -> DeleteDataCatalogOutputBuilder
Creates a new builder-style object to manufacture DeleteDataCatalogOutput.